==> vue-styleguidist-4.28.1.tgz: package/lib/client/rsg-components/Table/TableRenderer.js <==
import "core-js/modules/es.array.map";
import "core-js/modules/es.string.small";
import React from 'react';
import PropTypes from 'prop-types';
import Styled from 'rsg-components/Styled';
import cx from 'classnames';
export var styles = function styles(_ref) {
  var space = _ref.space,
      color = _ref.color,
      fontFamily = _ref.fontFamily,
      fontSize = _ref.fontSize;
  return {
    table: {
      width: '100%',
      borderCollapse: 'collapse',
      marginBottom: space[6]
    },
    tableHead: {
      borderBottom: [[1, color.border, 'solid']]
    },
    cellHeading: {
      color: color.base,
      paddingRight: space[2],
      paddingBottom: space[1],
      textAlign: 'left',
      fontFamily: fontFamily.base,
      fontWeight: 'bold',
      fontSize: fontSize.small,
      whiteSpace: 'nowrap'
    },
    dataRow: {
      '&:hover': {
        background: '#fbfbfb'
      }
    },
    cell: {
      color: color.base,
      paddingRight: space[2],
      paddingTop: space[1],
      paddingBottom: space[1],
      verticalAlign: 'top',
      fontFamily: fontFamily.base,
      fontSize: fontSize.small,
      borderBottom: [[1, color.border, 'solid']],
      '& div': {
        isolate: false,
        minWidth: 300
      }
    }
  };
};
export function TableRenderer(_ref2) {
  var classes = _ref2.classes,
      columns = _ref2.columns,
      rows = _ref2.rows,
      getRowKey = _ref2.getRowKey;
  return React.createElement("table", {
    className: classes.table
  }, React.createElement("thead", {
    className: classes.tableHead
  }, React.createElement("tr", null, columns.map(function (_ref3) {
    var caption = _ref3.caption;
    return React.createElement("th", {
      key: caption,
      className: classes.cellHeading
    }, caption);
  }))), React.createElement("tbody", null, rows.map(function (row) {
    return React.createElement("tr", {
      key: getRowKey(row),
      className: classes.dataRow
    }, columns.map(function (_ref4, index) {
      var render = _ref4.render,
          className = _ref4.className;
      return React.createElement("td", {
        key: index,
        className: cx(classes.cell, className)
      }, render(row));
    }));
  })));
}
TableRenderer.propTypes = {
  classes: PropTypes.object.isRequired,
  columns: PropTypes.arrayOf(PropTypes.shape({
    caption: PropTypes.string.isRequired,
    render: PropTypes.func.isRequired
  })).isRequired,
  rows: PropTypes.arrayOf(PropTypes.object).isRequired,
  getRowKey: PropTypes.func.isRequired
};
export default Styled(styles)(TableRenderer);

==> vue-styleguidist-4.33.1.tgz: package/lib/client/rsg-components/Table/TableRenderer.js <==
import "core-js/modules/es.array.map";
import "core-js/modules/es.string.small";
import React from 'react';
import PropTypes from 'prop-types';
import Styled from 'rsg-components/Styled';
import cx from 'classnames';
export var styles = function styles(_ref) {
  var space = _ref.space,
      color = _ref.color,
      fontFamily = _ref.fontFamily,
      fontSize = _ref.fontSize;
  return {
    table: {
      width: '100%',
      borderCollapse: 'collapse',
      marginBottom: space[6]
    },
    tableHead: {
      borderBottom: [[1, color.border, 'solid']]
    },
    cellHeading: {
      color: color.base,
      paddingRight: space[2],
      paddingBottom: space[1],
      textAlign: 'left',
      fontFamily: fontFamily.base,
      fontWeight: 'bold',
      fontSize: fontSize.small,
      whiteSpace: 'nowrap'
    },
    dataRow: {
      '&:hover': {
        background: '#fbfbfb'
      }
    },
    cell: {
      color: color.base,
      paddingRight: space[2],
      paddingTop: space[1],
      paddingBottom: space[1],
      verticalAlign: 'top',
      fontFamily: fontFamily.base,
      fontSize: fontSize.small,
      borderBottom: [[1, color.border, 'solid']],
      '& div': {
        isolate: false,
        minWidth: 300
      }
    }
  };
};
export function TableRenderer(_ref2) {
  var classes = _ref2.classes,
      columns = _ref2.columns,
      rows = _ref2.rows,
      getRowKey = _ref2.getRowKey;
  return /*#__PURE__*/React.createElement("table", {
    className: classes.table
  }, /*#__PURE__*/React.createElement("thead", {
    className: classes.tableHead
  }, /*#__PURE__*/React.createElement("tr", null, columns.map(function (_ref3) {
    var caption = _ref3.caption;
    return /*#__PURE__*/React.createElement("th", {
      key: caption,
      className: classes.cellHeading
    }, caption);
  }))), /*#__PURE__*/React.createElement("tbody", null, rows.map(function (row) {
    return /*#__PURE__*/React.createElement("tr", {
      key: getRowKey(row),
      className: classes.dataRow
    }, columns.map(function (_ref4, index) {
      var render = _ref4.render,
          className = _ref4.className;
      return /*#__PURE__*/React.createElement("td", {
        key: index,
        className: cx(classes.cell, className)
      }, render(row));
    }));
  })));
}
TableRenderer.propTypes = {
  classes: PropTypes.object.isRequired,
  columns: PropTypes.arrayOf(PropTypes.shape({
    caption: PropTypes.string.isRequired,
    render: PropTypes.func.isRequired
  })).isRequired,
  rows: PropTypes.arrayOf(PropTypes.object).isRequired,
  getRowKey: PropTypes.func.isRequired
};
export default Styled(styles)(TableRenderer);
